@@ -185,14 +185,9 @@ int ScriptCpu::compileScript()
 
     if( m_getCpuReg || m_getStrReg )
     {
-        m_mcu->createWatcher();
-    }
-    if( m_command || m_script.contains("toConsole") )  /// Use TextComponent ???
-    {
-        m_mcu->createWatcher();
-        m_watcher = m_mcu->getWatcher();
-        m_watcher->addConsole( this );
+        m_mcu->createWatcher( this );
     }
+
     for( ScriptPerif* perif : m_periferals ) perif->startScript();
 
     asIScriptFunction* func = m_aEngine->GetModule(0)->GetFunctionByDecl("void setup()");
@@ -215,13 +210,31 @@ void ScriptCpu::updateStep()
 
 void ScriptCpu::reset()
 {
+    m_watcher = m_mcu->getWatcher();
+
     m_mcuComp->setShowVal( true );
     m_value = "";
 
     if( m_reset ) callFunction( m_reset );
 }
-void ScriptCpu::voltChanged() { if( m_voltChanged ) callFunction( m_voltChanged ); }
-void ScriptCpu::runEvent()    { if( m_runEvent )    callFunction( m_runEvent ); }
+void ScriptCpu::voltChanged()
+{
+    if( !m_voltChanged ) return;
+    //callFunction( m_voltChanged );
+
+    m_status = m_context->executeJit0( m_voltChanged );
+    if( m_status != asEXECUTION_FINISHED ) printError();
+}
+
+void ScriptCpu::runEvent()
+{
+    if( !m_runEvent ) return;
+    //callFunction( m_runEvent );
+
+    m_status = m_context->executeJit0( m_runEvent );
+    if( m_status != asEXECUTION_FINISHED ) printError();
+}
+
 void ScriptCpu::INTERRUPT( uint vector )
 {
     prepare( m_INTERRUPT );
